@@ -500,7 +500,7 @@ extern void setgridtype(char *);
 extern void getgridtype(xcWidget, pointertype, caddr_t);
 extern void newlibrary(xcWidget, caddr_t, caddr_t);
 extern int findemptylib();
-extern int createlibrary();
+extern int createlibrary(Boolean);
 extern void newpagemenu(xcWidget, pointertype, caddr_t);
 extern void makepagebutton();
 extern void renamepage(short);
@@ -567,6 +567,7 @@ extern void createnets(objinstptr);
 extern void destroynets();
 extern Boolean nonnetwork(polyptr);
 extern int globalmax();
+extern LabellistPtr geninfolist(objectptr, objinstptr, char *);
 extern void gennetlist(objinstptr);
 extern void gencalls(objectptr);
 extern void search_on_siblings(objinstptr, objinstptr, pushlistptr,
@@ -692,6 +693,7 @@ extern Imagedata *addnewimage(char *, int, int);
 extern graphicptr new_graphic(objinstptr, char *, int, int);
 extern void invalidate_graphics(objectptr);
 extern void freegraphic(graphicptr);
+extern short *collect_graphics(short *);
 
 /* from render.c: */
 
@@ -718,7 +720,7 @@ extern Boolean render_client();
 
 /* from schema.c: */
 
-extern objectptr NameToPageObject(char *, objinstptr *);
+extern objectptr NameToPageObject(char *, objinstptr *, int *);
 extern objectptr NameToObject(char *, objinstptr *, Boolean);
 extern void callwritenet(xcWidget, pointertype, caddr_t);
 extern void doxschema(xcWidget, pointertype, caddr_t);
