@@ -966,6 +966,26 @@ void trackselarea()
    areastruct.save.y = newpos.y;
 }
 
+/*----------------------*/
+/* Track a rescale box	*/
+/*----------------------*/
+
+void trackrescale()
+{
+   XPoint newpos;
+   u_int  nullui;
+
+   newpos = UGetCursorPos();
+   if (newpos.x == areastruct.save.x && newpos.y == areastruct.save.y) return;
+
+   /* To be done---handle vs. editpart */
+   UDrawRescaleBox(areastruct.save);
+   UDrawRescaleBox(newpos);
+
+   areastruct.save.x = newpos.x;
+   areastruct.save.y = newpos.y;
+}
+
 /*----------------------------------------------------------------------*/
 /* Polygon distance comparison function for qsort			*/
 /*----------------------------------------------------------------------*/
