@@ -1192,7 +1192,7 @@ enum {
    XCF_Graphic	/* 100 */,	XCF_Rescale /* 101 */,
    XCF_Connectivity /* 102 */,	XCF_Sim /* 103 */,
    XCF_SPICE /* 104 */,		XCF_PCB /* 105 */,
-   XCF_SPICEflat /* 106 */,
+   XCF_SPICEflat /* 106 */,	XCF_Text_Delete_Param,	/* 107 */
    NUM_FUNCTIONS
 };
 
@@ -1325,6 +1325,7 @@ typedef struct {
 typedef struct {
    char		*tempfile;
    char		*tempdir;
+   short	do_replace;
    xcIntervalId	timeout_id;
    int		save_interval;
    u_short	new_changes;
